=== modified file 'bzrlib/changeset/serializer/v06.py'
--- bzrlib/changeset/serializer/v06.py	2005-11-20 01:37:41 +0000
+++ bzrlib/changeset/serializer/v06.py	2005-12-31 20:55:42 +0000
@@ -26,6 +26,8 @@
 from sha import sha
 from bzrlib.diff import internal_diff
 from bzrlib.delta import compare_trees
+from bzrlib.rio import RioWriter, read_stanzas
+from bzrlib.osutils import pathjoin
 
 
 class ChangesetSerializerV06(ChangesetSerializer):
@@ -153,15 +155,11 @@
         old_label = ''
         new_label = ''
 
-        def pjoin(*args):
-            # Only forward slashes in changesets
-            return os.path.join(*args).replace('\\', '/')
-
         def do_diff(old_path, file_id, new_path, kind):
             new_entry = new_tree.inventory[file_id]
             old_tree.inventory[file_id].diff(internal_diff,
-                    pjoin(old_label, old_path), old_tree,
-                    pjoin(new_label, new_path), new_entry, new_tree,
+                    pathjoin(old_label, old_path), old_tree,
+                    pathjoin(new_label, new_path), new_entry, new_tree,
                     self.to_file)
         def do_meta(file_id):
             ie = new_tree.inventory[file_id]
@@ -182,7 +180,7 @@
         for path, file_id, kind in delta.added:
             w('=== added %s %s // file-id:%s\n' % (kind, path, file_id))
             new_tree.inventory[file_id].diff(internal_diff,
-                    pjoin(new_label, path), new_tree,
+                    pathjoin(new_label, path), new_tree,
                     DEVNULL, None, None,
                     self.to_file, reverse=True)
 

=== renamed file 'bzrlib/changeset/old/patches.py' => 'bzrlib/patches.py'
=== modified file 'bzrlib/tests/__init__.py'
--- bzrlib/tests/__init__.py	2005-12-13 18:56:57 +0000
+++ bzrlib/tests/__init__.py	2005-12-31 20:55:42 +0000
@@ -37,6 +37,7 @@
 import bzrlib.plugin
 import bzrlib.store
 import bzrlib.trace
+import bzrlib.changeset.serializer
 from bzrlib.trace import mutter
 from bzrlib.tests.TestUtil import TestLoader, TestSuite
 from bzrlib.tests.treeshape import build_tree_contents
@@ -44,6 +45,7 @@
 MODULES_TO_TEST = []
 MODULES_TO_DOCTEST = [
                       bzrlib.branch,
+                      bzrlib.changeset.serializer,
                       bzrlib.commands,
                       bzrlib.errors,
                       bzrlib.inventory,
@@ -51,10 +53,14 @@
                       bzrlib.osutils,
                       bzrlib.store,
                       ]
+
+
 def packages_to_test():
     import bzrlib.tests.blackbox
+    import bzrlib.tests.changeset
     return [
-            bzrlib.tests.blackbox
+            bzrlib.tests.blackbox,
+            bzrlib.tests.changeset
             ]
 
 

=== added file 'bzrlib/tests/changeset/__init__.py'
--- bzrlib/tests/changeset/__init__.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/changeset/__init__.py	2005-12-31 20:55:42 +0000
@@ -0,0 +1,32 @@
+# Copyright (C) 2004-2006 by Canonical Ltd
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+from bzrlib.tests import TestLoader, TestSuite, _load_module_by_name
+from bzrlib.tests import TestCaseInTempDir, BzrTestBase
+
+
+def test_suite():
+    testmod_names = [
+        'bzrlib.tests.changeset.test_patches',
+    ]
+    suite = TestSuite()
+    loader = TestLoader()
+    for mod_name in testmod_names:
+        mod = _load_module_by_name(mod_name)
+        suite.addTest(loader.loadTestsFromModule(mod))
+    return suite
+
+

=== renamed file 'bzrlib/tests/changeset/__init__.py' => 'bzrlib/tests/changeset/old_tests.py'
--- bzrlib/tests/changeset/__init__.py	2005-12-05 12:27:37 +0000
+++ bzrlib/tests/changeset/old_tests.py	2005-12-31 20:55:42 +0000
@@ -1,7 +1,22 @@
+# Copyright (C) 2004-2006 by Canonical Ltd
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 from StringIO import StringIO
 
-from bzrlib.selftest import TestCaseInTempDir, TestCase
+from bzrlib.tests import TestCaseInTempDir, TestCase
 from bzrlib.errors import BzrError
 
 from bzrlib.diff import internal_diff
@@ -264,6 +279,7 @@
         ctree.note_last_changed("e", "revisionidiguess")
         self.assertEqual(self.sorted_ids(ctree), ['a', 'b', 'd', 'e'])
 
+
 class CSetTester(TestCaseInTempDir):
 
     def get_valid_cset(self, base_rev_id, rev_id,
@@ -490,9 +506,3 @@
         ##cset = self.get_valid_cset(None, 'a@cset-0-6', auto_commit=True)
 
 
-
-TEST_CLASSES = [
-    CTreeTester,
-    CSetTester
-]
-

=== added file 'bzrlib/tests/changeset/test_patches.py'
--- bzrlib/tests/changeset/test_patches.py	1970-01-01 00:00:00 +0000
+++ bzrlib/tests/changeset/test_patches.py	2005-12-31 20:55:42 +0000
@@ -0,0 +1,33 @@
+# Copyright (C) 2004-2006 by Canonical Ltd
+
+# This program is free software; you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation; either version 2 of the License, or
+# (at your option) any later version.
+
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+
+# You should have received a copy of the GNU General Public License
+# along with this program; if not, write to the Free Software
+# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+
+# Just import the tester built-into the patch file
+
+from bzrlib.patches import PatchesTester
+import os
+
+
+# We have to inherit so that unittest will consider it
+# Also, the testdata directory is relative to this file
+# so override datafile
+class TestPatches(PatchesTester):
+    
+    def datafile(self, filename):
+        data_path = os.path.join(os.path.dirname(__file__), "testdata", 
+                                 filename)
+        return file(data_path, "rb")
+
+

